@@ -302,8 +302,7 @@ gnome_vfs_ssl_create_from_fd (GnomeVFSSSL **handle_return,
 	gnutls_init (&ssl->private->tlsstate, GNUTLS_CLIENT);
 
 	/* set socket */
-	gnutls_transport_set_ptr (ssl->private->tlsstate, 
-				  GINT_TO_POINTER (fd));
+	gnutls_transport_set_ptr (ssl->private->tlsstate, fd);
 
 	gnutls_protocol_set_priority (ssl->private->tlsstate, protocol_priority);
 	gnutls_cipher_set_priority (ssl->private->tlsstate, cipher_priority);
